% Autokorrelationsfunktion und Autoleistungsspektrum fuer aequidistant abgetastete Signale mit wirklich streng periodischen Anteilen
% mit Slotkorrelation (als Referenz - langsam), hier ohne Gewichtung, Gewichtung in aperslotw.m
% Slotkorrelation, direkte Spektralschaetzung und FFT-Implementierung sollten identische Ergebnisse ergeben
function [tau,R,f,P]=aperslot(x,dt,NT)
  % x - Datensatz
  % dt - Zeitschritt
  % NT - angenommene Periodenlaenge
  N=length(x);
  tau=(0:NT-1)*dt;
  R1=zeros(1,NT);
  R0=zeros(1,NT);
  for i=1:N
    for j=1:N
      k=mod(j-i,NT)+1;
      R1(k)=R1(k)+x(i)*x(j);
      R0(k)=R0(k)+1;
    end
  end
  R=R1./R0;
  df=1/(NT*dt);
  f=(mod((0:NT-1)+fix(NT/2),NT)-fix(NT/2))*df;
  P=real(fft(R))/NT;
end

